# Copyright 2013-2023 Lawrence Livermore National Security, LLC and other
# Spack Project Developers. See the top-level COPYRIGHT file for details.
#
# SPDX-License-Identifier: (Apache-2.0 OR MIT)

from spack.package import *


class PyGetorganelle(PythonPackage):
    """Organelle Genome Assembly Toolkit (Chloroplast/Mitocondrial/ITS)"""

    homepage = "https://github.com/Kinggerm/GetOrganelle"
    url = "https://github.com/Kinggerm/GetOrganelle/archive/refs/tags/1.7.5.0.tar.gz"

    maintainers("dorton21")

    # renamed to getorganelle
    version(
        "1.7.5.0",
        sha256="c498196737726cb4c0158f23037bf301a069f5028ece729bb4d09c7d915df93d",
        deprecated=True,
    )

    depends_on("py-setuptools", type="build")
    depends_on("py-numpy@1.16.4:", type=("build", "run"))
    depends_on("py-scipy@1.3.0:", type=("build", "run"))
    depends_on("py-sympy@1.4:", type=("build", "run"))
    depends_on("py-requests", type=("build", "run"))

    depends_on("bowtie2", type="run")
    depends_on("spades", type="run")
    depends_on("blast-plus", type="run")

    # Allow access to relevant runtime scripts
    # I.e. get_organelle_config.py, get_organelle_from_reads.py, etc.
    def setup_run_environment(self, env):
        env.prepend_path("PATH", prefix)
        env.prepend_path("PATH", prefix.Utilities)
